@@ -1,24 +1,25 @@
-"""Extensions of collections.defaultdict w. dict conv. and pretty formatting"""
+"""Extension of collections.defaultdict"""
 
-import collections
+from collections import defaultdict
 
-from olutils.conversion import basedict, dict2str
+from olutils.conversion.dictionary import basedict, dict2str
 
 
-class DefaultDict(collections.defaultdict):
+class DefaultDict(defaultdict):
     """dict with default factory
 
-    Overload collections.defaultdict
+    Overload collections.defaultdict conversion to base dictionary and pretty
+    formatting.
     """
     def to_dict(self):
-        """Return base dictionary from self"""
+        """Return base dictionary from instance"""
         return basedict(self)
 
     def pstring(self, *args, **kwargs):
-        """Return pretty string of self
+        """Return pretty string of instance
 
         Args:
-            *args, **kwargs: @see olutils.conversion.dict2str
+            *args, **kwargs: @see `~olutils.dict2str`
 
         Return:
             (str)
@@ -29,7 +30,7 @@ class DefaultDict(collections.defaultdict):
         """Pretty print self
 
         Args:
-            *args, **kwargs: @see olutils.conversion.dict2str
+            *args, **kwargs: @see `~olutils.dict2str`
         """
         print(self.pstring(*args, **kwargs))
 
@@ -40,9 +41,9 @@ def defaultdict(default_factory, *args, **kwargs):
 
 
 def deepdefaultdict(default_factory, depth):
-    """Return a multi ladder defaultdict given the depth and the leaf frmt"""
+    """Return a multi ladder defaultdict given the leaf factory and depth"""
     if depth == 0:
-        return default_factory
+        return default_factory()
     if depth == 1:
         return defaultdict(default_factory)
     return defaultdict(lambda: deepdefaultdict(default_factory, depth-1))
